#!/bin/bash

DBUS_PATH=$1

function reset_hosts() {
    local str
    str=$(cat << EOF
127.0.0.1	localhost
127.0.1.1	$(hostname)

# The following lines are desirable for IPv6 capable hosts
::1     ip6-localhost ip6-loopback
fe00::0 ip6-localnet
ff00::0 ip6-mcastprefix
ff02::1 ip6-allnodes
ff02::2 ip6-allrouters
EOF
)

    echo "${str}" > /tmp/hosts
    SudoWrapper -s "cp /tmp/hosts /etc/hosts"
}

function modify_hosts() {
    local old_md5
    old_md5=$(md5sum /etc/hosts | awk '{print $1}')

    cp /etc/hosts /tmp/hosts
    ShowSimpleTextEditor "${DBUS_PATH}" "/tmp/hosts"
    SudoWrapper -s "cp /tmp/hosts /etc/hosts"

    local new_md5
    new_md5=$(md5sum /etc/hosts | awk '{print $1}')

    if [ "${old_md5}" != "${new_md5}" ]; then
        SudoWrapper -s "systemctl restart dnsmasq"
        SudoWrapper -s "systemctl restart network-manager"

        local msg="The modification has taken effect"
        local tr_msg
        tr_msg=$(Translate "${msg}")
        ShowMessageBox "${DBUS_PATH}" "${tr_msg}" "info"
    fi
}

function main() {
    local tr_str
    tr_str=$(Translate "Would you like to reset the hosts file to its original state before making changes?")

    local select
    select=$(ShowConfirmBox "${DBUS_PATH}" "${tr_str}" "question")
    if [ "${select}" == "yes" ]; then
        reset_hosts

        tr_str=$(Translate "Continue modifying the hosts file?")
        select=$(ShowConfirmBox "${DBUS_PATH}" "${tr_str}" "question")
        if [ "${select}" == "no" ]; then
            exit 0
        fi
    fi

    modify_hosts
}

main
